@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Engine/IO/Async.pm 2473 2007-09-04T07:08:58.221716Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Engine/IO/Async.pm 2912 2007-10-01T02:36:26.816021Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -65,7 +65,7 @@ sub send_request
     } else {
         $request->uri->host( $request->notes('resolved_ip') )
             if $request->notes('resolved_ip');
-        if ( $self->block_private_ip_address($c, $request, $request->uri->host)) {
+        if ( $self->block_private_ip_address($c, $request, $request->uri)) {
             return;
         }
         $self->start_request($c, $request);
